@media(min-width: 300px){.icon-list{grid-template-columns:repeat(2, 1fr)}}@media(min-width: 600px){.icon-list{grid-template-columns:repeat(5, 1fr)}}@media(min-width: 1300px){.icon-list{grid-template-columns:repeat(10, 1fr)}}@media(min-width: 2000px){.icon-list{grid-template-columns:repeat(15, 1fr)}}form#config_form{width:100%}form#config_form td{width:100%}form#config_form td input[type=text],form#config_form td input[type=url],form#config_form td input[type=email],form#config_form td input[type=password],form#config_form td textarea{width:80%}.submit-row a.button{display:block;background:#417690;border-radius:4px;padding:.625rem .9375rem;height:.9375rem;line-height:.9375rem;color:var(--button-fg)}.monitor-url{color:#000;padding:5px;margin-bottom:10px;background-color:rgba(255,255,255,.6)}.icon-list{display:grid;gap:5px;background-color:#e3e2e2;padding:10px}.icon-list .frame{border:1px solid #000;border-radius:2px;padding:10px;align-items:center;text-align:center;cursor:pointer}.icon-list .frame:hover{border-color:#fff}.icon-list .frame img{height:40px}.icon-list .frame label{color:#000}input[type=text]{width:100%}/*# sourceMappingURL=birder-admin.css.map */
